# adhoc-pdb
[![Build Status](https://travis-ci.org/yehonatanz/adhoc-pdb.svg?branch=master)](https://travis-ci.org/yehonatanz/adhoc-pdb)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![PyPI version](https://badge.fury.io/py/adhoc-pdb.svg)](https://pypi.org/project/adhoc-pdb/)

A simple tool that allows you to debug your system whenever you want, with no overhead, even in production!
